'''
Created by auto_sdk on 2017.04.14
'''
from top.api.base import RestApi
class JuItemsSearchRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.param_top_item_query = None

	def getapiname(self):
		return 'taobao.ju.items.search'



# -*- coding: utf-8 -*-
# @Time    : 2018/6/15 20:32
# @Author  : play4fun
# @File    : 淘宝客商品查询info.py
# @Software: PyCharm

"""
淘宝客商品查询info.py:
http://open.taobao.com/api.htm?docId=24518&docType=2
用处不大
"""

from top.api import TbkItemInfoGetRequest
from top import appinfo

from config import appkey,secret

req=TbkItemInfoGetRequest()
req.set_app_info(appinfo(appkey,secret))

req.num_iids="573322259356"
req.platform=2#链接形式：1：PC，2：无线，默认：１

try:
    resp= req.getResponse()

    it=resp['tbk_item_info_get_response']['results']['n_tbk_item'][0]
    print(it)

    import json

    # ds = json.dumps(resp)
    # print(ds)
except Exception as e:
    print(e)

'''
{'cat_leaf_name': '调和油', 'cat_name': '粮油米面/南北干货/调味品', 'item_url': 'https://detail.m.tmall.com/item.htm?id=530672343155', 'material_lib_type': '', 'nick': '天猫超市', 'num_iid': 530672343155, 'pict_url': 'https://img.alicdn.com/bao/uploaded/i2/725677994/TB2Zg7sc3TqK1RjSZPhXXXfOFXa_!!725677994-0-sm.jpg', 'provcity': '上海', 'reserve_price': '199.9', 'seller_id': 725677994, 'small_images': {'string': ['https://img.alicdn.com/i3/725677994/TB2lrBCpAKWBuNjy1zjXXcOypXa_!!725677994.jpg', 'https://img.alicdn.com/i2/725677994/TB2cDTdpDlYBeNjSszcXXbwhFXa_!!725677994.jpg', 'https://img.alicdn.com/i3/725677994/TB2eepSprGYBuNjy0FoXXciBFXa_!!725677994.jpg', 'https://img.alicdn.com/i1/725677994/TB2ZWfaeQZmBKNjSZPiXXXFNVXa_!!725677994.jpg']}, 'title': '金龙鱼 葵花籽清香食用油调和油5L*4 食用油', 'user_type': 1, 'volume': 10831, 'zk_final_price': '199.9'}
'''

'''
{
    "tbk_item_info_get_response": {
        "results": {
            "n_tbk_item": [
                {
                    "cat_leaf_name": "半身裙",
                    "cat_name": "女装/女士精品",
                    "item_url": "https://item.taobao.com/item.htm?id=569885087264",
                    "nick": "lee官方旗舰店",
                    "num_iid": 569885087264,
                    "pict_url": "https://img.alicdn.com/bao/uploaded/i1/928622636/TB1WI44ueuSBuNjy1XcXXcYjFXa_!!0-item_pic.jpg",
                    "provcity": "上海",
                    "reserve_price": "990",
                    "seller_id": 928622636,
                    "small_images": {
                        "string": [
                            "https://img.alicdn.com/i3/928622636/TB2hmPNXQT85uJjSZFgXXcZvVXa_!!928622636.jpg",
                            "https://img.alicdn.com/i3/928622636/TB2QtCRobsTMeJjSsziXXcdwXXa_!!928622636.jpg",
                            "https://img.alicdn.com/i2/928622636/TB2zArNXOP85uJjSZFKXXcw7FXa_!!928622636.jpg",
                            "https://img.alicdn.com/i2/928622636/TB2R3_CobsTMeJjSszhXXcGCFXa_!!928622636.jpg"
                        ]
                    },
                    "title": "Lee女装 2017秋冬新品双口袋时尚休闲牛仔背带短裙 L29975Z02898",
                    "user_type": 1,
                    "volume": 29,
                    "zk_final_price": "449"
                }
            ]
        },
        "request_id": "10fclulaghcir"
    }
}
'''


# -*- coding: utf-8 -*-
# @Time    : 2018/5/27 16:13
# @Author  : play4fun
# @File    : 淘宝客商品链接转换1.py
# @Software: PyCharm

"""
淘宝客商品链接转换1.py:
http://open.taobao.com/api.htm?docId=24516&docType=2
有权限了

现在可以
"""
import traceback

from top.api import  TbkItemConvertRequest
from top import appinfo

from config import appkey,secret
req=TbkItemConvertRequest()
req.set_app_info(appinfo(appkey,secret))
# req.set_app_info(appinfo("24728514",'847aff038c548e44adeeb7fd634d6cc2'))#也没有权限

req.fields="num_iid,click_url"
#https://detail.tmall.com/item.htm?id=572473824056
req.num_iids="573551640025"#,566807961895"# 商品ID串，用','分割，从taobao.tbk.item.get接口获取num_iid字段，最大40个

# req.adzone_id=adzone_id#只能是【网站广告位】
# req.adzone_id=1814028435#成功 #广告位ID，区分效果位置
req.adzone_id=26807050116#mm_128160800_117150173_24917900229
#24921350189 adzone_id不正确

req.platform=2#链接形式：1：PC，2：无线，默认：１
# req.unid="demo"#自定义输入串，英文和数字组成，长度不能大于12个字符，区分不同的推广渠道
# req.dx="1"

try:
    resp= req.getResponse()
    import json
    # print(resp)

    ds = json.dumps(resp)
    print(ds)#成功
    '''
    {'tbk_item_convert_response': 
    {'request_id': 'sbotxvt1as81',
  'results': 
  {'n_tbk_item': 
  [{'click_url': 'https://s.click.taobao.com/t?e=m%3D2%26s%3DuvdckrSoU18cQipKwQzePOeEDrYVVa64XoO8tOebS%2BdRAdhuF14FMd2%2BYEKtRXLMMMgx22UI05aUZR70%2BlK9qVurOGJDe30MkDfIHRGCqXtWah4BbUeGMu%2FBas0tvb4eZz42eVlqqJTf1lozC%2BSXTPdFsh68tKJt%2FNI%2BDXrnOcZv%2FEPE%2FQzyzwtRW0nH3Ls%2BVJ%2B%2BVg%2FftcXcNzTJORRJBj2l4PysJx%2FP',
  
     'num_iid': 572935458344}]}}}
    '''
except Exception as e:
    print(e)
    traceback.print_exc()


# -*- coding: utf-8 -*-
# @Time    : 2018/4/29 15:26
# @Author  : play4fun
# @File    : 解析淘口令1.py
# @Software: PyCharm

"""
解析淘口令1.py:
"""

from top.api import WirelessShareTpwdQueryRequest
from top import appinfo
appkey = "24728341"
secret = "b29db0fb6fd58bf51be896035e5d8f69"

def parseTKL(msg):
    req=WirelessShareTpwdQueryRequest()
    req.set_app_info(appinfo(appkey,secret))
    req.password_content=msg

    rt=req.getResponse()
    return rt

def test1():#复制框内整段文字，打开「手淘」即可「领取优惠券」并购买￥MDGGba1MLQh￥
    # msg='【杭州真丝上衣女2018新款短袖t恤夏桑蚕丝处理清仓 重磅铜氨丝女装,这款真丝t恤，宽松的版型设计，上身非常显瘦】，復·制这段描述€08skb3DzfQC€后咑閞👉淘♂寳♀👈'#商品口令
    msg='€ARq0b3xVoOw€'#领券
    rt=parseTKL(msg)
    print(rt)

if __name__ == '__main__':
    test1()
    '''
    {'wireless_share_tpwd_query_response': {'content': '杭州真丝上衣女2018新款短袖t恤夏桑蚕丝处理清仓 重磅铜氨丝女装',
  'native_url': 'tbopen://m.taobao.com/tbopen/index.html?action=ali.open.nav&module=h5&h5Url=https%3A%2F%2Fa.m.taobao.com%2Fi572456021063.htm%3Fprice%3D198%26original_price%3D688%26sourceType%3Ditem%26sourceType%3Ditem%26suid%3Dd2109373-8046-4f3f-8b1d-172c4741dc5d%26ut_sk%3D1.Wthts%252FH5I4QDANNejADzdUSC_21646297_1536555233541.TaoPassword-WeiXin.1%26un%3D817be46c5b6cc1dfb463cb48fb1832e7%26share_crt_v%3D1%26mit_nlg_ver%3Dv1%26sp_tk%3D4oKsMDhza2IzRHpmUUPigqw%3D%26spm%3Da211b4.24728341%26visa%3D13a09278fde22a2e%26disablePopup%3Dtrue%26disableSJ%3D1&appkey=24728341&visa=13a09278fde22a2e',
  'pic_url': 'http://gw.alicdn.com/bao/uploaded/i1/2198430295/TB16g0zlcUrBKNjSZPxXXX00pXa_!!0-item_pic.jpg',
  'price': '198.00',
  'request_id': '10qsc7l1tri39',
  'suc': True,
  'thumb_pic_url': 'http://gw.alicdn.com/bao/uploaded/i1/2198430295/TB16g0zlcUrBKNjSZPxXXX00pXa_!!0-item_pic.jpg_170x170.jpg',
  'title': '淘口令-宝贝',
  
  'url': 'https://a.m.taobao.com/i572456021063.htm?price=198&original_price=688&sourceType=item&sourceType=item&suid=d2109373-8046-4f3f-8b1d-172c4741dc5d&ut_sk=1.Wthts%2FH5I4QDANNejADzdUSC_21646297_1536555233541.TaoPassword-WeiXin.1&un=817be46c5b6cc1dfb463cb48fb1832e7&share_crt_v=1&mit_nlg_ver=v1&sp_tk=4oKsMDhza2IzRHpmUUPigqw=&spm=a211b4.24728341&visa=13a09278fde22a2e&disablePopup=true&disableSJ=1'
  }}
    '''

    '''
    {'wireless_share_tpwd_query_response': 
    {'content': '半身裙套装女2018新款时尚潮 港风省心搭配女装上衣短裙两件套夏',
  'native_url': 'tbopen://m.taobao.com/tbopen/index.html?action=ali.open.nav&module=h5&h5Url=https%3A%2F%2Fitem.taobao.com%2Fitem.htm%3Fid%3D567873872517%26ut_sk%3D1.utdid_24728341_1536566411927.TaoPassword-Outside.isv%26sp_tk%3D4oKsQVJxMGIzeFZvT3figqw%3D%26spm%3Da211b4.24728341%26visa%3D13a09278fde22a2e%26disablePopup%3Dtrue%26disableSJ%3D1&appkey=24728341&visa=13a09278fde22a2e',
  'pic_url': 'http://img.alicdn.com/bao/uploaded/i4/595412874/TB2SOfPm7KWBuNjy1zjXXcOypXa_!!595412874.jpg',
  'request_id': 'u259wsbbqld2',
  'suc': True,
  'thumb_pic_url': 'http://img.alicdn.com/bao/uploaded/i4/595412874/TB2SOfPm7KWBuNjy1zjXXcOypXa_!!595412874.jpg_170x170.jpg',
  'title': '淘口令-页面',
  
  'url': 'https://item.taobao.com/item.htm?id=567873872517&ut_sk=1.utdid_24728341_1536566411927.TaoPassword-Outside.isv&sp_tk=4oKsQVJxMGIzeFZvT3figqw=&spm=a211b4.24728341&visa=13a09278fde22a2e&disablePopup=true&disableSJ=1'}}
    '''


# -*- coding: utf-8 -*-
# @Time    : 2018/10/25 18:37
# @Author  : play4fun
# @File    : 导购信息搜索1.py
# @Software: PyCharm

"""
导购信息搜索1.py:
参考：https://doc.alidayu.com/docs/api.htm?apiId=35896

佣金
优惠券
"""

import top.api

# req = top.api.TbkDgMaterialOptionalRequest(url, port)
# req.set_app_info(top.appinfo(appkey, secret))

import traceback, json

from top.api import TbkDgMaterialOptionalRequest
from top import appinfo

from config import appkey, secret

req2 = TbkDgMaterialOptionalRequest()
req2.set_app_info(appinfo(appkey, secret))

req2.start_dsr = 10

req2.page_size = 20
req2.page_no = 1
req2.platform = 1
# req.end_tk_rate = 1234 #TODO 设置一个区间
# req.start_tk_rate = 1234
req2.end_price = 10
req2.start_price = 20
# req.is_overseas = False#报错
# req.is_tmall = False
req2.sort = "tk_rate_des"
# req.itemloc = "杭州"
req2.cat = "16,18"
req2.q = "女装"
req2.material_id = 2836
# req.has_coupon = True
# req.ip = "13.2.33.4"
req2.adzone_id = 26807050116
# req.need_free_shipment = True
# req.need_prepay = True
# req.include_pay_rate_30 = True
# req.include_good_rate = True
# req.include_rfd_rate = True
# req.npx_level = 2
# req.end_ka_tk_rate = 1234
# req.start_ka_tk_rate = 1234
# req.device_encrypt = "MD5"
# req.device_value = "xxx"
# req.device_type = "IMEI"
try:
    resp = req2.getResponse()
    print(resp)
    print('\n')
    ds = json.dumps(resp)
    # print(ds)  # 成功
    print('----------')
    for item in resp['tbk_dg_material_optional_response']['result_list']['map_data']:
        if item['coupon_remain_count']>0:
            print(item)
        else:
            print('No')
except Exception as e:
    print(e)
    '''
{
    "category_id": 50010850,
    "category_name": "连衣裙",
    "commission_rate": "7000",
    "commission_type": "ZX",
    "coupon_id": "",
    "coupon_info": "",
    "coupon_remain_count": 0,
    "coupon_total_count": 0,
    "include_dxjh": "false",
    "include_mkt": "false",
    "info_dxjh": "{}",
    "item_url": "https://item.taobao.com/item.htm?id=578808249791",
    "level_one_category_id": 16,
    "level_one_category_name": "女装/女士精品",
    "num_iid": 578808249791,
    "pict_url": "https://img.alicdn.com/bao/uploaded/i4/833450195/O1CN011DJLhEdyid51HxL_!!0-item_pic.jpg",
    "provcity": "浙江 杭州",
    "reserve_price": "10",
    "seller_id": 833450195,
    "shop_dsr": 50000,
    "shop_title": "店主VX: zzq518899",
    "short_title": "微商女装一手货源招代理一件代发",
    "title": "微商女装一手货源招代理一件代发欧泰货服装加盟厂家直销韩版高端",
    "tk_total_commi": "0",
    "tk_total_sales": "0",
    "url": "//s.click.taobao.com/t?e=m%3D2%26s%3DemdAmL8lW2McQipKwQzePOeEDrYVVa64lwnaF1WLQxlyINtkUhsv0GqskRXq8a9LngqExHzB0EJwe9WqVoWbK6cpCeoIkU8NSlFUVq0truStrs69PUsRSCQjO9J4i5qlSD99OVE0eUgdcoJn23In8lUM%2FAmuI%2FSW5UwZupjob08v3l3uT7Tftfr%2BRoxyUbBM3IwrKPeZEd%2FfkS3Jgs7fdqJn5AyUbPoV&scm=null&pvid=100_11.182.80.100_19664_4071540466096948180&app_pvid=59590_11.11.60.245_338_1540466096944&ptl=floorId:2836;pvid:100_11.182.80.100_19664_4071540466096948180;app_pvid:59590_11.11.60.245_338_1540466096944&union_lens=lensId:0b0b3cf5_0c79_166aaef3c4e_361d",
    "user_type": 0,
    "volume": 0,
    "white_image": "",
    "zk_final_price": "10"
}    
    '''



'''
Created by auto_sdk on 2018.07.25
https://open-doc.dingtalk.com/docs/api.htm?apiId=24523

淘宝客店铺链接转换
'''
from top.api.base import RestApi


class TbkShopConvertRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.adzone_id = None
        self.fields = None
        self.platform = None
        self.unid = None
        self.user_ids = None

    def getapiname(self):
        return 'taobao.tbk.shop.convert'



'''
Created by auto_sdk on 2018.04.09
'''
from top.api.base import RestApi
class TbkDgNewuserOrderGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.adzone_id = None
		self.end_register_time = None
		self.page_no = None
		self.page_size = None
		self.start_register_time = None

	def getapiname(self):
		return 'taobao.tbk.dg.newuser.order.get'



# -*- coding: utf-8 -*-
# @Time    : 2018/11/1 15:50
# @Author  : play4fun
# @File    : 淘口令转链1.py
# @Software: PyCharm

"""
淘口令转链1.py:
"""

from top.api import TbkTpwdConvertRequest
from top import appinfo

from config import appkey, secret

req = TbkTpwdConvertRequest()
req.set_app_info(appinfo(appkey, secret))

req.password_content = "￥dAEYbi4KO4D￥"#原链接
# req.password_content = "￥TvFnbi4rS28￥"#转链之后的，优惠券
req.adzone_id = 26807050116
req.dx = "1"

try:
    resp = req.getResponse()

    # it=resp['tbk_item_info_get_response']['results']['n_tbk_item'][0]
    # print(it)

    import json

    ds = json.dumps(resp)
    print(ds)
except Exception as e:
    print(e)
    '''
{
    "tbk_tpwd_convert_response": {
        "data": {
            "click_url": "https://s.click.taobao.com/t?e=m%3D2%26s%3DlPB%2BIFlTXXYcQipKwQzePOeEDrYVVa64XoO8tOebS%2BdRAdhuF14FMQPx4A86vneat4hWD5k2kjOUZR70%2BlK9qVurOGJDe30Mi4iGkEp3vhY1bHXFwOOwIlnifR7TequSVbyFvQb68TVhzIPRUbx8%2FC%2FoxewA8MDczd4sm6IVoF5BvG9Dt0tL1PUA8sxeHPJeLm7IGu8cWyae94Djkt%2FJYSGFCzYOOqAQ&union_lens=lensId:0b177a9d_0c35_166ce44e330_566b",
            
            "num_iid": "576016341093"
        },
        "request_id": "81f43dtpbscl"
    }
}


把别人的淘口令转成自己的淘口令
{
    "tbk_tpwd_convert_response": {
        "data": {
            "click_url": "https://s.click.taobao.com/t?e=m%3D2%26s%3Dsnn8QvJbTiwcQipKwQzePOeEDrYVVa64XoO8tOebS%2BdRAdhuF14FMZ6IEgctIxHz1aH1Hk3GeOiUZR70%2BlK9qVurOGJDe30Mi4iGkEp3vhY1bHXFwOOwIlnifR7TequSVbyFvQb68TVhzIPRUbx8%2FC%2FoxewA8MDczd4sm6IVoF5BvG9Dt0tL1PUA8sxeHPJeLm7IGu8cWyae94Djkt%2FJYSGFCzYOOqAQ&union_lens=lensId:0b01eedb_0d43_166ce482533_5605",
            "num_iid": "576016341093"
        },
        "request_id": "64ifmu0jz018"
    }
}

    '''



'''
Created by auto_sdk on 2014.03.27
'''
from top.api.base import RestApi
class TopatsTaskDeleteRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.task_id = None

	def getapiname(self):
		return 'taobao.topats.task.delete'



# -*- coding: utf-8 -*-
'''
Created by auto_sdk on 2018.07.25
【导购】链接转换-根据商品ID获取该商品的优惠券
参考
http://open.taobao.com/api.htm?docId=29289&docType=2&scopeId=12486

'''
from top.api.base import RestApi


class TbkCouponConvertRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.adzone_id = None
        self.item_id = None
        self.me = None  # 营销计划链接中的me参数
        self.platform = None

    def getapiname(self):
        return 'taobao.tbk.coupon.convert'



# -*- coding: utf-8 -*-
# @Time    : 2018/7/13 18:11
# @Author  : play4fun
# @File    : 整个流程1.py
# @Software: PyCharm

"""
整个流程1.py:
"""

from top.api import WirelessShareTpwdQueryRequest, TbkTpwdCreateRequest
from top.api import TbkItemConvertRequest
from top import appinfo
from config import appkey, secret
from urllib.parse import urlparse, parse_qs


def parseTKL(msg):
    req = WirelessShareTpwdQueryRequest()
    req.set_app_info(appinfo(appkey, secret))
    req.password_content = msg

    rt = req.getResponse()
    return rt


if __name__ == '__main__':
    # tkl = '''【2018夏季新款女装薄款白色打底内衣性感漏肩内搭背心吊带短款上衣】http://m.tb.cn/h.3XYA5IW 点击链接，再选择浏览器咑閞；或復·制这段描述€g1IVbaMXxxK€后到👉淘♂寳♀👈'''
    tkl = '''【法国菜特价3】http://m.tb.cn/h.3cCldb1 点击链接，再选择浏览器咑閞；或復·制这段描述€qJC7baMSryl€后到👉淘♂寳♀👈'''

    rt = parseTKL(tkl)
    print(rt)
    '''
    {'wireless_share_tpwd_query_response': {'content': '2018夏季新款女装薄款白色打底内衣性感漏肩内搭背心吊带短款上衣', 'native_url': 'tbopen://m.taobao.com/tbopen/index.html?action=ali.open.nav&module=h5&h5Url=https%3A%2F%2Fitem.taobao.com%2Fitem.htm%3Fut_sk%3D1.WkpqTyOBZbADAJxSRs4G0pnb_21380790_1531476850118.PanelQRCode.1%26id%3D568295190230%26sourceType%3Ditem%26price%3D128%26suid%3DB93FAA0C-781F-4C40-961E-93B3911BED21%26un%3D6a0b666299f236be8bd7bab98ffeb263%26share_crt_v%3D1%26sp_tk%3D4oKsZzFJVmJhTVh4eEvigqw%3D%26spm%3Da211b4.24728341%26visa%3D13a09278fde22a2e%26disablePopup%3Dtrue%26disableSJ%3D1&appkey=24728341&visa=13a09278fde22a2e', 'pic_url': 'http://gw.alicdn.com/bao/uploaded/i2/381329993/TB2xzdWfvuSBuNkHFqDXXXfhVXa_!!381329993.jpg', 'price': '128.00', 'suc': True, 'thumb_pic_url': 'http://gw.alicdn.com/bao/uploaded/i2/381329993/TB2xzdWfvuSBuNkHFqDXXXfhVXa_!!381329993.jpg_170x170.jpg', 'title': '淘口令-宝贝', 'url': 'https://item.taobao.com/item.htm?ut_sk=1.WkpqTyOBZbADAJxSRs4G0pnb_21380790_1531476850118.PanelQRCode.1&id=568295190230&sourceType=item&price=128&suid=B93FAA0C-781F-4C40-961E-93B3911BED21&un=6a0b666299f236be8bd7bab98ffeb263&share_crt_v=1&sp_tk=4oKsZzFJVmJhTVh4eEvigqw=&spm=a211b4.24728341&visa=13a09278fde22a2e&disablePopup=true&disableSJ=1', 'request_id': '92ocdpxbz17j'}}
    '''
    url = rt['wireless_share_tpwd_query_response']['url']
    content = rt['wireless_share_tpwd_query_response']['content']
    price = rt['wireless_share_tpwd_query_response']['price']
    pic_url = rt['wireless_share_tpwd_query_response']['pic_url']
    p1 = urlparse(url)
    qs1 = parse_qs(p1.query)
    gid = qs1.get('id', None)[0]
    print(content, price, gid)
    #
    req = TbkItemConvertRequest()
    req.set_app_info(appinfo(appkey, secret))
    req.fields = "click_url"
    req.num_iids = gid  # ,566807961895"# 商品ID串，用','分割，从taobao.tbk.item.get接口获取num_iid字段，最大40个
    # req.adzone_id=adzone_id
    req.adzone_id = 1814028435  # 成功 #广告位ID，区分效果位置
    resp = req.getResponse()
    # import json
    # ds = json.dumps(resp)
    click_url = resp['tbk_item_convert_response']['results']['n_tbk_item'][0]['click_url']
    print(click_url)
    # 创建淘口令
    req = TbkTpwdCreateRequest()
    req.set_app_info(appinfo(appkey, secret))
    req.text = content
    req.url = click_url
    req.logo = pic_url
    resp = req.getResponse()
    # ds = json.dumps(resp)
    print(resp)
    print(resp['tbk_tpwd_create_response']['data']['model'])  # ￥j8V0baMTi6H￥
    print('成功转链')



'''
Created by auto_sdk on 2017.12.20
'''
from top.api.base import RestApi
class WirelessShareTpwdQueryRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.password_content = None

	def getapiname(self):
		return 'taobao.wireless.share.tpwd.query'



# -*- coding: utf-8 -*-
'''
Created on 2012-6-29

@author: lihao
'''

__version__ = '18.11.18'
__author__ = 'play4fun <play4fun@foxmail.com>'

from top.api.base import sign


class appinfo(object):
    def __init__(self, appkey, secret):
        self.appkey = appkey
        self.secret = secret


def getDefaultAppInfo():
    pass


def setDefaultAppInfo(appkey, secret):
    default = appinfo(appkey, secret)
    global getDefaultAppInfo
    getDefaultAppInfo = lambda: default



# -*- coding: utf-8 -*-
# @Time    : 2018/4/29 17:02
# @Author  : play4fun
# @File    : 创建淘口令2.py
# @Software: PyCharm

"""
创建淘口令2.py:

过期了？
submsg=不合法ApiName，ApiName = taobao.wireless.share.tpwd.create
"""

from top.api import WirelessShareTpwdCreateRequest
from top import appinfo
import config,json
req=WirelessShareTpwdCreateRequest()
req.set_app_info(appinfo(config.appkey,config.secret))

text='2018夏季新款女装时尚黑色V领拼接收腰A字裙中长款雪纺显瘦连衣裙'
url='https://uland.taobao.com/coupon/edetail?e=JBuZPm5JWqEGQASttHIRqZL3pImL%2FJh1HZ6yD2Py5i%2Fg4lUqifPvH9x2%2FlD7wOdrVxl2CHuUpj1uWNE2q%2FyjycWKxy1EFPIVsSKwS%2F%2FvFcFma4VUO7VGBlZrtTOLgXkcjDppvlX%2Bob%2BBtHA6T8TZnVBPfopb7LXvu8n6e%2B0RLoCEsG9BMdsVqA%3D%3D&traceId=0bb6999515405448411741149e&union_lens=lensId:0b0ad4b4_0bf5_166afa0c5f0_c4b9'
logo='https://img.alicdn.com/bao/uploaded/i1/587451667/TB23sxjrviSBuNkSnhJXXbDcpXa_!!587451667.jpg_220x220_.webp'
d={'url':url,'text':text,'logo':logo}
param=json.dumps(d)
req.tpwd_param=param

try:
    resp= req.getResponse()
    import json

    ds = json.dumps(resp)
    print(ds)
    print(resp['wireless_share_tpwd_create_response']['model'])
except Exception as e:
    print(e)
    '''
    {'wireless_share_tpwd_create_response': 
    {'model': '€bzp3b3xUpDI€',
  'request_id': '3qxi481xxgei'}}
    '''


'''
Created by auto_sdk on 2018.10.29

https://jaq-doc.alibaba.com/docs/api.htm?apiId=37884


taobao.tbk.sc.optimus.material (淘宝客擎天柱通用物料API - 社交)
￥免费
需要授权
通用物料推荐，传入官方公布的物料id，可获取指定物料
'''
from top.api.base import RestApi


class TbkScOptimusMaterialRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.adzone_id = None
        self.content_id = None
        self.content_source = None
        self.device_encrypt = None
        self.device_type = None
        self.device_value = None
        self.material_id = None
        self.page_no = None
        self.page_size = None
        self.site_id = None

    def getapiname(self):
        return 'taobao.tbk.sc.optimus.material'



# -*- coding: utf-8 -*-
# @Time    : 2018/4/29 17:20
# @Author  : play4fun
# @File    : 淘宝客返利订单查询1.py
# @Software: PyCharm

"""
淘宝客返利订单查询1.py:
没权限

errorcode=40 message=Missing required arguments:activity_id subcode=None submsg=None application_host=11.11.49.179 service_host=top011011049179.na62

"""
from top.api import TbkDgNewuserOrderGetRequest
import top,config
req=TbkDgNewuserOrderGetRequest()
req.set_app_info(top.appinfo(config.appkey, config.secret))

req.fields = "tb_trade_parent_id,tb_trade_id,num_iid,item_title,item_num,price,pay_price,seller_nick,seller_shop_title,commission,commission_rate,unid,create_time,earning_time"
req.start_time = "2018-08-05 13:52:08"
req.span = 600
req.page_no = 1
req.page_size = 100

try:
    resp= req.getResponse()
    import json

    ds = json.dumps(resp)
    print(ds)
except Exception as e:
    print(e)


# -*- coding: utf-8 -*-
# @Time    : 2018/6/16 07:22
# @Author  : play4fun
# @File    : 获取淘宝联盟选品库列表1.py
# @Software: PyCharm

"""
获取淘宝联盟选品库列表1.py:
没有权限
"""

import traceback

from top.api import TbkItemConvertRequest ,TbkUatmFavoritesGetRequest
from top import appinfo

from test.config import appkey, secret

req = TbkItemConvertRequest()
req.set_app_info(appinfo(appkey, secret))
# req.set_app_info(appinfo("24728514",'847aff038c548e44adeeb7fd634d6cc2'))#也没有权限

req.page_no=1
req.page_size=20
req.fields="favorites_title,favorites_id,type"
req.type=1

try:
    resp = req.getResponse()
    import json

    print(resp)

    ds = json.dumps(resp)
    print(ds)
except Exception as e:
    print(e)
    traceback.print_exc()



# -*- coding: utf-8 -*-
# @Time    : 2018/8/26 11:29
# @Author  : play4fun
# @File    : 订单查询1.py
# @Software: PyCharm

"""
订单查询1.py:
http://open.taobao.com/api.htm?docId=24527&docType=2

"""

from top.api import TbkOrderGetRequest
from top import appinfo

from config import appkey,secret

req=TbkOrderGetRequest()
req.set_app_info(appinfo(appkey,secret))


req.fields = "tb_trade_parent_id,tb_trade_id,num_iid,item_title,item_num,price,pay_price,seller_nick,seller_shop_title,commission,commission_rate,unid,create_time,earning_time,tk3rd_pub_id,tk3rd_site_id,tk3rd_adzone_id,relation_id"
req.start_time = "2018-08-23 12:18:22"
req.span = 600
req.page_no = 1
req.page_size = 20
req.tk_status = 1
req.order_query_type = "settle_time"
try:
    resp = req.getResponse()
    print(resp)
except Exception as e:
    print(e)
    #http://open.taobao.com/doc.htm?spm=a219a.7386653.0.0.CudPbJ&docId=1&docType=18
    '''
    错误原因：应用没有权限访问当当前API
    解决方案：申请相应的API权限
    
    {"error_response":{"code":11,"msg":"Insufficient isv permissions","sub_code":"isv.permission-api-package-limit","sub_msg":"scope ids is 381 11655 13168 11998 12486 11653","request_id":"10enths0uz5vu"}}
    
    '''




# -*- coding: utf-8 -*-
# @Time    : 2018/4/29 17:22
# @Author  : play4fun
# @File    : 淘宝客新用户订单API_导购1.py
# @Software: PyCharm

"""
淘宝客新用户订单API_导购1.py:
"""

from top.api import TbkDgNewuserOrderGetRequest
from top import appinfo
import config

req=TbkDgNewuserOrderGetRequest()
req.set_app_info(appinfo(config.appkey,config.secret))

req.page_size=20
req.adzone_id=154150379#mm_128160800_41488987_177810904
# mm_128160800_40192372_154150379
# mm_18989874_43894087_376356913
req.page_no=1
req.start_register_time="2018-07-24 00:00:00"
req.end_register_time="2018-07-27 00:00:00"


try:
    resp= req.getResponse()
    import json

    ds = json.dumps(resp)
    print(ds)
except Exception as e:
    print(e)


'''
Created by auto_sdk on 2018.10.29

http://open.taobao.com/api.htm?docId=33947&docType=2

taobao.tbk.dg.optimus.material( 淘宝客物料下行-导购 )
￥免费不需用户授权
通用物料推荐，传入官方公布的物料id，可获取指定物料
'''
from top.api.base import RestApi


class TbkDgOptimusMaterialRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.adzone_id = None
        self.content_id = None
        self.content_source = None
        self.device_encrypt = None
        self.device_type = None
        self.device_value = None
        self.material_id = None
        self.page_no = None
        self.page_size = None

    def getapiname(self):
        return 'taobao.tbk.dg.optimus.material'



# -*- coding: utf-8 -*-
# @Time    : 2018/5/27 16:08
# @Author  : play4fun
# @File    : TbkItemConvertRequest.py
# @Software: PyCharm

"""
TbkItemConvertRequest.py:
taobao.tbk.item.convert (淘宝客商品链接转换)
文档 http://open.taobao.com/doc2/apiDetail.htm?apiId=24516&scopeId=11653
要申请权限才能调用
"""

from top.api.base import RestApi

class TbkItemConvertRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.fields = None
        self.num_iids = None
        self.platform = None
        self.adzone_id = None
        self.unid = None
        self.dx = None

    def getapiname(self):
        return 'taobao.tbk.item.convert'


# -*- coding: utf-8 -*-
# @Time    : 2018/8/26 11:23
# @Author  : play4fun
# @File    : TbkOrderGetRequest.py
# @Software: PyCharm

"""
TbkOrderGetRequest.py:
需要申请权限，否则不能用

参考
https://github.com/xiaobozi/tdd/blob/c10a6a423ba256c53934ddf698a4f8ceecbed99e/src/Top/Request/TbkOrderGetRequest.php

文档
http://open.taobao.com/api.htm?docId=24527&docType=2

"""

from top.api.base import RestApi


class TbkOrderGetRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        # self.adzone_id = None
        # self.site_id = None
        #
        self.activity_id = None# 不知道？
        self.fields = None#需返回的字段列表
        self.start_time = None#订单查询开始时间
        self.span = None#订单查询时间范围,单位:秒,最小60,最大600,默认60
        self.page_no = None
        self.page_size = None
        self.tk_status = None#非必须，订单状态，1: 全部订单，3：订单结算，12：订单付款， 13：订单失效，14：订单成功； 订单查询类型为‘结算时间’时，只能查订单结算状态
        self.order_query_type = None#订单查询类型，创建时间“create_time”，或结算时间“settle_time”

    def getapiname(self):
        return 'taobao.tbk.order.get'



'''
Created by auto_sdk on 2018.08.31

https://open-doc.dingtalk.com/docs/api.htm?apiId=32932

taobao.tbk.tpwd.convert (淘口令转链)
￥免费
不需要授权
支持通过淘口令解析商品id，并提供对应的淘客转链接


反向解析：淘口令-->s.click.taobao.com链接

把别人的淘口令转成自己的淘口令
'''
from top.api.base import RestApi


class TbkTpwdConvertRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.adzone_id = None
        self.dx = None  # 1表示商品转通用计划链接，其他值或不传表示优先转营销计划链接
        self.password_content = None  # 需要解析的淘口令

    def getapiname(self):
        return 'taobao.tbk.tpwd.convert'



'''
Created by auto_sdk on 2017.09.05

http://open.taobao.com/api.htm?docId=24518&docType=2

'''
from top.api.base import RestApi


class TbkItemInfoGetRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.fields = None
        self.num_iids = None
        self.platform = None

    def getapiname(self):
        return 'taobao.tbk.item.info.get'



# -*- coding: utf-8 -*-
# @Time    : 2018/4/29 16:52
# @Author  : play4fun
# @File    : 创建淘口令1.py
# @Software: PyCharm

"""
创建淘口令1.py:
http://open.taobao.com/docs/api.htm?apiId=31127

这个能转换【优惠券-长链接】
"""

from top.api import TbkTpwdCreateRequest
from top import appinfo
import config

req=TbkTpwdCreateRequest()
req.set_app_info(appinfo(config.appkey,config.secret))

# req.text='半身裙套装女2018新款时尚潮 港风省心搭配女装上衣短裙两件套夏'
req.text='大众11-17款新帕萨特改装车门防踢垫保护垫专用装饰不锈钢防踢板'
# req.url='https://item.taobao.com/item.htm?id=567873872517'
req.url='https://uland.taobao.com/coupon/edetail?e=JBuZPm5JWqEGQASttHIRqZL3pImL%2FJh1HZ6yD2Py5i%2Fg4lUqifPvH9x2%2FlD7wOdrVxl2CHuUpj1uWNE2q%2FyjycWKxy1EFPIVsSKwS%2F%2FvFcFma4VUO7VGBlZrtTOLgXkcjDppvlX%2Bob%2BBtHA6T8TZnVBPfopb7LXvu8n6e%2B0RLoCEsG9BMdsVqA%3D%3D&traceId=0bb6999515405448411741149e&union_lens=lensId:0b0ad4b4_0bf5_166afa0c5f0_c4b9'
# req.logo=''
# req.tpwd_param

try:
    resp= req.getResponse()
    import json

    ds = json.dumps(resp)
    print(ds)
    print(resp['tbk_tpwd_create_response']['data']['model'])
    #{"tbk_tpwd_create_response": {"data": {"model": "\uffe5cqtQbS9y8gR\uffe5"}, "request_id": "41yh5cdyclhc"}}
    #￥cqtQbS9y8gR￥
except Exception as e:
    print(e)


'''
Created by auto_sdk on 2017.12.18

下线了！
淘口令API在开放平台下线公告
发布于: 2018-9-10 13:40:35

尊敬的开发者

      您好。基于综合考虑，淘口令接口taobao.wireless.share.tpwd.create计划在开放平台下线，ISV对该接口的调用申请也将关闭。具体下线计划：该接口新申请入口关闭时间为2018年9月11日24:00。针对已有权限者，该接口关闭的时间为2018年9月27日24:00。为免影响您的业务，请已有权限者及时停止使用该接口功能，由此造成的不便深表歉意 。

--阿里巴巴.开放平台

2018年9月10日

submsg=不合法ApiName，ApiName = taobao.wireless.share.tpwd.create
'''
from top.api.base import RestApi


class WirelessShareTpwdCreateRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.tpwd_param = None

    def getapiname(self):
        return 'taobao.wireless.share.tpwd.create'



# -*- coding: utf-8 -*-
'''
Created by auto_sdk on 2018.04.02
参考：
https://doc.alidayu.com/docs/api.htm?apiId=35896
'''
from top.api.base import RestApi


class TbkDgMaterialOptionalRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.adzone_id = None  # mm_xxx_xxx_xxx的第三位
        self.material_id = None  # 官方的物料Id(详细物料id见：https://tbk.bbs.taobao.com/detail.html?appId=45301&postId=8576096)，不传时默认为2836
        self.cat = None  # 后台类目ID，用,分割，最大10个，该ID可以通过taobao.itemcats.get接口获取到
        self.end_price = None
        self.ip = None  # ip参数影响邮费获取，如果不传或者传入不准确，邮费无法精准提供

        self.start_tk_rate = None
        self.end_tk_rate = None  # 淘客佣金比率上限，如：1234表示12.34%

        self.has_coupon = None
        self.is_overseas = None  # 是否海外商品，设置为true表示该商品是属于海外商品，设置为false或不设置表示不判断这个属性
        self.is_tmall = None
        self.itemloc = None  # 所在地
        self.page_no = None
        self.page_size = None
        self.platform = None  # 链接形式：1：PC，2：无线，默认：１
        self.q = None  # 查询词
        self.sort = None  # 排序_des（降序），排序_asc（升序），销量（total_sales），淘客佣金比率（tk_rate）， 累计推广量（tk_total_sales），总支出佣金（tk_total_commi），价格（price）
        self.start_dsr = None  # 店铺dsr评分，筛选高于等于当前设置的店铺dsr评分的商品0-50000之间
        self.start_price = None
        self.npx_level = None  # 牛皮癣程度，取值：1:不限，2:无，3:轻微

    def getapiname(self):
        return 'taobao.tbk.dg.material.optional'



# -*- coding: utf-8 -*-
# @Time    : 2018/4/29 15:12
# @Author  : play4fun
# @File    : get_rebate_order.py
# @Software: PyCharm

"""
get_rebate_order.py:
"""

# import top
from top import api as tbk_api

import top.api



url=''
port=''


# req = top.api.TbkRebateOrderGetRequest(url, port)
req = top.api.TbkRebateOrderGetRequest()
req.set_app_info(top.appinfo(appkey, secret))

req.fields = "tb_trade_parent_id,tb_trade_id,num_iid,item_title,item_num,price,pay_price,seller_nick,seller_shop_title,commission,commission_rate,unid,create_time,earning_time"
req.start_time = "2015-03-05 13:52:08"
req.span = 600
req.page_no = 1
req.page_size = 20
try:
    resp = req.getResponse()
    print(resp)
except Exception as e:
    print(e)


# -*- coding: utf-8 -*-
'''
Created by auto_sdk on 2018.04.04

http://open.taobao.com/docs/api.htm?apiId=31127
'''
from top.api.base import RestApi


class TbkTpwdCreateRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.ext = None
        self.logo = None
        self.text = None
        self.url = None
        self.user_id = None

    def getapiname(self):
        return 'taobao.tbk.tpwd.create'



'''
Created by auto_sdk on 2018.07.20

https://open-doc.dingtalk.com/docs/api.htm?apiId=36837

taobao.tbk.sc.newuser.order.sum (拉新活动汇总API--社交)
'''
from top.api.base import RestApi


class TbkScNewuserOrderSumRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.activity_id = None
        self.adzone_id = None
        self.page_no = None
        self.page_size = None
        self.settle_month = None
        self.site_id = None

    def getapiname(self):
        return 'taobao.tbk.sc.newuser.order.sum'



# -*- coding: utf-8 -*-
from top.api.rest.TbkShopRecommendGetRequest import TbkShopRecommendGetRequest
from top.api.rest.TbkTpwdCreateRequest import TbkTpwdCreateRequest
from top.api.rest.TbkJuTqgGetRequest import TbkJuTqgGetRequest
from top.api.rest.TbkDgNewuserOrderGetRequest import TbkDgNewuserOrderGetRequest
from top.api.rest.TopSecretRegisterRequest import TopSecretRegisterRequest
from top.api.rest.TbkCouponGetRequest import TbkCouponGetRequest
from top.api.rest.TbkItemGetRequest import TbkItemGetRequest
from top.api.rest.TbkUatmEventGetRequest import TbkUatmEventGetRequest
from top.api.rest.OpenuidGetBytradeRequest import OpenuidGetBytradeRequest
from top.api.rest.TbkItemInfoGetRequest import TbkItemInfoGetRequest
from top.api.rest.TimeGetRequest import TimeGetRequest
from top.api.rest.TbkUatmEventItemGetRequest import TbkUatmEventItemGetRequest
from top.api.rest.TbkScMaterialOptionalRequest import TbkScMaterialOptionalRequest
from top.api.rest.TopSecretGetRequest import TopSecretGetRequest
from top.api.rest.OpenuidChangeRequest import OpenuidChangeRequest
from top.api.rest.OpenuidGetRequest import OpenuidGetRequest
from top.api.rest.OpenuidGetBymixnickRequest import OpenuidGetBymixnickRequest
from top.api.rest.TopAuthTokenRefreshRequest import TopAuthTokenRefreshRequest
from top.api.rest.TbkShopGetRequest import TbkShopGetRequest
from top.api.rest.AreasGetRequest import AreasGetRequest
from top.api.rest.TopatsTaskDeleteRequest import TopatsTaskDeleteRequest
from top.api.rest.KfcKeywordSearchRequest import KfcKeywordSearchRequest
from top.api.rest.HttpdnsGetRequest import HttpdnsGetRequest
from top.api.rest.TbkDgItemCouponGetRequest import TbkDgItemCouponGetRequest
from top.api.rest.TbkUatmFavoritesGetRequest import TbkUatmFavoritesGetRequest
from top.api.rest.TopSdkFeedbackUploadRequest import TopSdkFeedbackUploadRequest
from top.api.rest.TopAuthTokenCreateRequest import TopAuthTokenCreateRequest
from top.api.rest.TbkScNewuserOrderGetRequest import TbkScNewuserOrderGetRequest
from top.api.rest.WirelessShareTpwdCreateRequest import WirelessShareTpwdCreateRequest
from top.api.rest.AppipGetRequest import AppipGetRequest
from top.api.rest.TbkDgMaterialOptionalRequest import TbkDgMaterialOptionalRequest
from top.api.rest.TopatsResultGetRequest import TopatsResultGetRequest
from top.api.rest.TopIpoutGetRequest import TopIpoutGetRequest
from top.api.rest.WirelessShareTpwdQueryRequest import WirelessShareTpwdQueryRequest
from top.api.rest.TbkUatmFavoritesItemGetRequest import TbkUatmFavoritesItemGetRequest
from top.api.rest.TbkSpreadGetRequest import TbkSpreadGetRequest
from top.api.rest.TbkItemRecommendGetRequest import TbkItemRecommendGetRequest
from top.api.rest.FilesGetRequest import FilesGetRequest
from top.api.rest.JuItemsSearchRequest import JuItemsSearchRequest
from top.api.rest.TbkItemConvertRequest import TbkItemConvertRequest
# 新添加的
from top.api.rest.TbkOrderGetRequest import TbkOrderGetRequest
from top.api.rest.TbkCouponConvertRequest import TbkCouponConvertRequest
# 2018.11.1
from top.api.rest.TbkShopConvertRequest import TbkShopConvertRequest
from top.api.rest.TbkScOptimusMaterialRequest import TbkScOptimusMaterialRequest
from top.api.rest.TbkTpwdConvertRequest import TbkTpwdConvertRequest
from top.api.rest.TbkScNewuserOrderSumRequest import TbkScNewuserOrderSumRequest
from top.api.rest.TbkDgNewuserOrderSumRequest import TbkDgNewuserOrderSumRequest
from top.api.rest.TbkDgOptimusMaterialRequest import TbkDgOptimusMaterialRequest
#



'''
Created by auto_sdk on 2018.04.02
'''
from top.api.base import RestApi
class TbkScMaterialOptionalRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.adzone_id = None
		self.cat = None
		self.end_price = None
		self.end_tk_rate = None
		self.has_coupon = None
		self.is_overseas = None
		self.is_tmall = None
		self.itemloc = None
		self.page_no = None
		self.page_size = None
		self.platform = None
		self.q = None
		self.site_id = None
		self.sort = None
		self.start_dsr = None
		self.start_price = None
		self.start_tk_rate = None

	def getapiname(self):
		return 'taobao.tbk.sc.material.optional'



# -*- coding: utf-8 -*-
# @Time    : 2018/9/17 18:27
# @Author  : play4fun
# @File    : 获取淘宝联盟定向招商的宝贝信息1.py
# @Software: PyCharm

"""
获取淘宝联盟定向招商的宝贝信息1.py:
没用
"""

from top.api import TbkUatmEventItemGetRequest
from top import appinfo

from config import appkey,secret

req=TbkUatmEventItemGetRequest()
req.set_app_info(appinfo(appkey,secret))

req.num_iids="575968998243"
req.platform=1
req.page_size=20
req.adzone_id=34567#推广位id，需要在淘宝联盟后台创建；且属于appkey对应的备案媒体id（siteid），如何获取adzoneid，请参考：http://club.alimama.com/read-htm-tid-6333967.html?spm=0.0.0.0.msZnx5
req.unid="3456"
req.event_id=123456#招商活动id
req.page_no=1
req.fields="num_iid,title,pict_url,small_images,reserve_price,zk_final_price,user_type,provcity,item_url,seller_id,volume,nick,shop_title,zk_final_price_wap,event_start_time,event_end_time,tk_rate,type,status"
try:
    resp= req.getResponse()
    import json

    ds = json.dumps(resp)
    print(ds)
except Exception as e:
    print(e)


# -*- coding: utf-8 -*-
# @Time    : 2018/4/29 15:28
# @Author  : play4fun
# @File    : config.py
# @Software: PyCharm

"""
config.py:
"""

#大星发星东网
appkey = "24728341"
secret = "b29db0fb6fd58bf51be896035e5d8f69"


#绘读
appkey2 = "24728514"
secret2 = "847aff038c548e44adeeb7fd634d6cc2"


# -*- coding: utf-8 -*-
'''
Created on 2012-6-29

@author: lijie.ma
'''
from aliyun.api.base import sign



class appinfo(object):
    def __init__(self,accessKeyId,accessKeySecret):
        self.accessKeyId = accessKeyId
        self.accessKeySecret = accessKeySecret
        
def getDefaultAppInfo():
    pass

     
def setDefaultAppInfo(accessKeyId,accessKeySecret):
    default = appinfo(accessKeyId,accessKeySecret)
    global getDefaultAppInfo 
    getDefaultAppInfo = lambda: default
    




    




#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(
    name='topsdk',
    version='18.11.18',#按日期
    author='top',
    author_email='xuteng.xt@alibaba-inc.com',
    packages=find_packages(),
    install_requires=[],
    license='MIT',
)




# -*- coding: utf-8 -*-
# @Time    : 2018/9/17 18:33
# @Author  : play4fun
# @File    : 淘宝客商品关联推荐查询1.py
# @Software: PyCharm

"""
淘宝客商品关联推荐查询1.py:
可以用
还是没有佣金

返回 列表
"""

from top.api import TbkItemRecommendGetRequest
from top import appinfo

from config import appkey, secret

req = TbkItemRecommendGetRequest()
req.set_app_info(appinfo(appkey, secret))

req.fields="num_iid,title,pict_url,small_images,reserve_price,zk_final_price,user_type,provcity,item_url"
req.num_iid = "568659766675"
req.platform = 2  # 链接形式：1：PC，2：无线，默认：１
req.count = 40

try:
    resp = req.getResponse()
    import json

    ds = json.dumps(resp)
    print(ds)
except Exception as e:
    print(e)
    '''
     {
        "item_url": "http://h5.m.taobao.com/awp/core/detail.htm?id=572151163766",
        "num_iid": 572151163766,
        "pict_url": "https://img.alicdn.com/tfscom/i1/587451667/TB23sxjrviSBuNkSnhJXXbDcpXa_!!587451667.jpg",
        "provcity": "浙江 杭州",
        "reserve_price": "598.00",
        "small_images": {
            "string": [
                "https://img.alicdn.com/tfscom/i3/587451667/TB2eGONiY3nBKNjSZFMXXaUSFXa_!!587451667.jpg",
                "https://img.alicdn.com/tfscom/i3/587451667/TB2AR.DtRyWBuNkSmFPXXXguVXa_!!587451667.jpg",
                "https://img.alicdn.com/tfscom/i1/587451667/TB2LKAUCYuWBuNjSszgXXb8jVXa_!!587451667.jpg",
                "https://img.alicdn.com/tfscom/i2/587451667/TB2jf3qvm8YBeNkSnb4XXaevFXa_!!587451667.jpg"
            ]
        },
        "title": "2018夏季新款女装时尚黑色V领拼接收腰A字裙中长款雪纺显瘦连衣裙",
        "user_type": 0,
        "zk_final_price": "168.00"
    },
    '''



# -*- coding: utf-8 -*-
# @Time    : 2018/10/26 11:19
# @Author  : play4fun
# @File    : 获取佣金和优惠券1.py
# @Software: PyCharm

"""
获取佣金和优惠券1.py:
"""

from top.api import TbkItemInfoGetRequest, TbkDgMaterialOptionalRequest
from top import appinfo

from config import appkey, secret

req = TbkItemInfoGetRequest()
req.set_app_info(appinfo(appkey, secret))

req2 = TbkDgMaterialOptionalRequest()
req2.set_app_info(appinfo(appkey, secret))

req.num_iids = "577221455881"
req.platform = 2  # 链接形式：1：PC，2：无线，默认：１

try:
    resp = req.getResponse()

    it = resp['tbk_item_info_get_response']['results']['n_tbk_item'][0]
    print(it)
    '''
{'cat_leaf_name': '大码女装',
 'cat_name': '女装/女士精品',
 'item_url': 'https://h5.m.taobao.com/awp/core/detail.htm?id=577221455881',
 'material_lib_type': '',
 'nick': '广州柔星专业大码女装',
 'num_iid': 577221455881,
 'pict_url': 'https://img.alicdn.com/bao/uploaded/i2/3013701358/O1CN011Lu0JUOoBV9CpWD_!!3013701358.jpg',
 'provcity': '广东 广州',
 'reserve_price': '65',
 'seller_id': 3013701358,
 'small_images': {'string': ['https://img.alicdn.com/i2/3013701358/O1CN011Lu0JVlIA3JxtKV_!!3013701358.jpg',
   'https://img.alicdn.com/i2/3013701358/O1CN011Lu0JWKHHkqVdjm_!!3013701358.jpg',
   'https://img.alicdn.com/i4/3013701358/O1CN011Lu0JWt91aSzSWa_!!3013701358.jpg',
   'https://img.alicdn.com/i4/3013701358/O1CN011Lu0JWWMFP8TxNM_!!3013701358.jpg']},
 'title': '秋冬新款羽绒棉大码中年女装时尚休闲拼接夹棉中长棉衣长袖连衣裙',
 'user_type': 0,
 'volume': 44,
 'zk_final_price': '65'}    
    '''

    import json

    # ds = json.dumps(resp)
    # print(ds)

    #
    # req2.start_dsr = 10

    req2.page_size = 20
    req2.page_no = 1
    req2.platform = 1
    # req.end_tk_rate = 1234 #TODO 设置一个区间
    # req.start_tk_rate = 1234
    req2.end_price = it['zk_final_price']
    req2.start_price = it['zk_final_price']
    # req.is_overseas = False#报错
    # req.is_tmall = False
    req2.sort = "tk_rate_des"
    # req.itemloc = "杭州"
    req2.cat = "16,18"
    req2.q = it['title']
    req2.material_id = 2836
    # req.has_coupon = True
    # req.ip = "13.2.33.4"
    req2.adzone_id = 26807050116
    # req.need_free_shipment = True
    # req.need_prepay = True
    # req.include_pay_rate_30 = True
    # req.include_good_rate = True
    # req.include_rfd_rate = True
    # req.npx_level = 2
    # req.end_ka_tk_rate = 1234
    # req.start_ka_tk_rate = 1234
    # req.device_encrypt = "MD5"
    # req.device_value = "xxx"
    # req.device_type = "IMEI"
    try:
        resp = req2.getResponse()
        print(resp)
        print('\n')
        ds = json.dumps(resp)
        # print(ds)  # 成功
        print('----------')
        for item in resp['tbk_dg_material_optional_response']['result_list']['map_data']:
            if item['coupon_remain_count'] > 0:
                print(item)
            else:
                print('No')
    except Exception as e:
        print(e)

except Exception as e:
    print(e)



# -*- coding: utf-8 -*-
# @Time    : 2018/10/26 17:02
# @Author  : play4fun
# @File    : 导购-链接转换1.py
# @Software: PyCharm

"""
导购-链接转换1.py:
"""

from top.api import TbkCouponConvertRequest
from top import appinfo

from config import appkey, secret

req = TbkCouponConvertRequest()
req.set_app_info(appinfo(appkey, secret))

req.item_id = 573790446309
req.adzone_id = 26807050116
req.platform = 2  # 链接形式：1：PC，2：无线，默认：１
# req.me = "dsdfsdadgsa" #me参数不合法

try:
    resp = req.getResponse()

    # it = resp['tbk_item_info_get_response']['results']['n_tbk_item'][0]
    # print(it)

    import json

    ds = json.dumps(resp)
    print(ds)
except Exception as e:
    print(e)
    '''
{
    "result": {
        "results": {
            "campaign_type": 0,
            "category_id": 16,
            "coupon_click_url": "https://uland.taobao.com/coupon/edetail?e=JBuZPm5JWqEGQASttHIRqZL3pImL%2FJh1HZ6yD2Py5i%2Fg4lUqifPvH9x2%2FlD7wOdrVxl2CHuUpj1uWNE2q%2FyjycWKxy1EFPIVsSKwS%2F%2FvFcFma4VUO7VGBlZrtTOLgXkcjDppvlX%2Bob%2BBtHA6T8TZnVBPfopb7LXvu8n6e%2B0RLoCEsG9BMdsVqA%3D%3D&traceId=0bb6999515405448411741149e&union_lens=lensId:0b0ad4b4_0bf5_166afa0c5f0_c4b9",
            "coupon_end_time": "2018-10-31",
            "coupon_info": "满20元减3元",
            "coupon_remain_count": 97713,
            "coupon_start_time": "2018-10-11",
            "coupon_total_count": 100000,
            "item_id": 577221455881,
            "item_url": "https://s.click.taobao.com/t?e=m%3D2%26s%3Dgy4sKsJMmeJw4vFB6t2Z2ueEDrYVVa64LKpWJ%2Bin0XLLWlSKdGSYDiqSD1piiUwDRitN3%2FurF3yUZR70%2BlK9qVurOGJDe30Mi4iGkEp3vhY1bHXFwOOwIjqdUmXHECnnQlDOBn9aemSpQ9xdsBJHs%2F1SarTXhIOTjr5I55N9ec%2BxG0GudCypDaAFWUUKjwsKxg5p7bh%2BFbQ%3D&union_lens=lensId:0b0ad4b4_0bf5_166afa0c5f0_c4b9",
            "max_commission_rate": "10.00"
        }
    },
    "request_id": "bdxe9dpr4mq4"
}    
    '''



'''
Created by auto_sdk on 2016.07.25
'''
from top.api.base import RestApi


class TbkItemGetRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.cat = None
        self.end_price = None
        self.end_tk_rate = None
        self.fields = None
        self.is_overseas = None
        self.is_tmall = None
        self.itemloc = None
        self.page_no = None
        self.page_size = None
        self.platform = None
        self.q = None
        self.sort = None
        self.start_price = None
        self.start_tk_rate = None

    def getapiname(self):
        return 'taobao.tbk.item.get'
